@@ -13,14 +13,20 @@
  * Include these files as needed.
  * See config.mk PLATFORM_xxx configuration parameters.
  */
+#include <sbi_utils/ipi/aclint_mswi.h>
 #include <sbi_utils/irqchip/plic.h>
 #include <sbi_utils/serial/uart8250.h>
-#include <sbi_utils/sys/clint.h>
+#include <sbi_utils/timer/aclint_mtimer.h>
 
 #define PLATFORM_PLIC_ADDR		0xc000000
 #define PLATFORM_PLIC_NUM_SOURCES	128
 #define PLATFORM_HART_COUNT		4
 #define PLATFORM_CLINT_ADDR		0x2000000
+#define PLATFORM_ACLINT_MTIMER_FREQ	10000000
+#define PLATFORM_ACLINT_MSWI_ADDR	(PLATFORM_CLINT_ADDR + \
+					 CLINT_MSWI_OFFSET)
+#define PLATFORM_ACLINT_MTIMER_ADDR	(PLATFORM_CLINT_ADDR + \
+					 CLINT_MTIMER_OFFSET)
 #define PLATFORM_UART_ADDR		0x09000000
 #define PLATFORM_UART_INPUT_FREQ	10000000
 #define PLATFORM_UART_BAUDRATE		115200
@@ -30,8 +36,21 @@ static struct plic_data plic = {
 	.num_src = PLATFORM_PLIC_NUM_SOURCES,
 };
 
-static struct clint_data clint = {
-	.addr = PLATFORM_CLINT_ADDR,
+static struct aclint_mswi_data mswi = {
+	.addr = PLATFORM_ACLINT_MSWI_ADDR,
+	.size = ACLINT_MSWI_SIZE,
+	.first_hartid = 0,
+	.hart_count = PLATFORM_HART_COUNT,
+};
+
+static struct aclint_mtimer_data mtimer = {
+	.mtime_freq = PLATFORM_ACLINT_MTIMER_FREQ,
+	.mtime_addr = PLATFORM_ACLINT_MTIMER_ADDR +
+		      ACLINT_DEFAULT_MTIME_OFFSET,
+	.mtime_size = ACLINT_DEFAULT_MTIME_SIZE,
+	.mtimecmp_addr = PLATFORM_ACLINT_MTIMER_ADDR +
+			 ACLINT_DEFAULT_MTIMECMP_OFFSET,
+	.mtimecmp_size = ACLINT_DEFAULT_MTIMECMP_SIZE,
 	.first_hartid = 0,
 	.hart_count = PLATFORM_HART_COUNT,
 	.has_64bit_mmio = TRUE,
@@ -63,23 +82,6 @@ static int platform_console_init(void)
 			     PLATFORM_UART_BAUDRATE, 0, 1);
 }
 
-/*
- * Write a character to the platform console output.
- */
-static void platform_console_putc(char ch)
-{
-	/* Example if the generic UART8250 driver is used */
-	uart8250_putc(ch);
-}
-
-/*
- * Read a character from the platform console input.
- */
-static int platform_console_getc(void)
-{
-	return uart8250_getc();
-}
-
 /*
  * Initialize the platform interrupt controller for current HART.
  */
@@ -105,32 +107,14 @@ static int platform_ipi_init(bool cold_boot)
 {
 	int ret;
 
-	/* Example if the generic CLINT driver is used */
+	/* Example if the generic ACLINT driver is used */
 	if (cold_boot) {
-		ret = clint_cold_ipi_init(&clint);
+		ret = aclint_mswi_cold_init(&mswi);
 		if (ret)
 			return ret;
 	}
 
-	return clint_warm_ipi_init();
-}
-
-/*
- * Send IPI to a target HART
- */
-static void platform_ipi_send(u32 target_hart)
-{
-	/* Example if the generic CLINT driver is used */
-	clint_ipi_send(target_hart);
-}
-
-/*
- * Clear IPI for a target HART.
- */
-static void platform_ipi_clear(u32 target_hart)
-{
-	/* Example if the generic CLINT driver is used */
-	clint_ipi_clear(target_hart);
+	return aclint_mswi_warm_init();
 }
 
 /*
@@ -140,56 +124,14 @@ static int platform_timer_init(bool cold_boot)
 {
 	int ret;
 
-	/* Example if the generic CLINT driver is used */
+	/* Example if the generic ACLINT driver is used */
 	if (cold_boot) {
-		ret = clint_cold_timer_init(&clint, NULL);
+		ret = aclint_mtimer_cold_init(&mtimer, NULL);
 		if (ret)
 			return ret;
 	}
 
-	return clint_warm_timer_init();
-}
-
-/*
- * Get platform timer value.
- */
-static u64 platform_timer_value(void)
-{
-	/* Example if the generic CLINT driver is used */
-	return clint_timer_value();
-}
-
-/*
- * Start platform timer event for current HART.
- */
-static void platform_timer_event_start(u64 next_event)
-{
-	/* Example if the generic CLINT driver is used */
-	clint_timer_event_start(next_event);
-}
-
-/*
- * Stop platform timer event for current HART.
- */
-static void platform_timer_event_stop(void)
-{
-	/* Example if the generic CLINT driver is used */
-	clint_timer_event_stop();
-}
-
-/*
- * Check reset type and reason supported by the platform.
- */
-static int platform_system_reset_check(u32 type, u32 reason)
-{
-	return 0;
-}
-
-/*
- * Reset the platform.
- */
-static void platform_system_reset(u32 type, u32 reason)
-{
+	return aclint_mtimer_warm_init();
 }
 
 /*
@@ -198,19 +140,10 @@ static void platform_system_reset(u32 type, u32 reason)
 const struct sbi_platform_operations platform_ops = {
 	.early_init		= platform_early_init,
 	.final_init		= platform_final_init,
-	.console_putc		= platform_console_putc,
-	.console_getc		= platform_console_getc,
 	.console_init		= platform_console_init,
 	.irqchip_init		= platform_irqchip_init,
-	.ipi_send		= platform_ipi_send,
-	.ipi_clear		= platform_ipi_clear,
 	.ipi_init		= platform_ipi_init,
-	.timer_value		= platform_timer_value,
-	.timer_event_stop	= platform_timer_event_stop,
-	.timer_event_start	= platform_timer_event_start,
-	.timer_init		= platform_timer_init,
-	.system_reset_check	= platform_system_reset_check,
-	.system_reset		= platform_system_reset
+	.timer_init		= platform_timer_init
 };
 const struct sbi_platform platform = {
 	.opensbi_version	= OPENSBI_VERSION,
